#ifndef TESTU01_H
#define TESTU01_H

#include "bbattery.h"
#include "fcho.h"
#include "fcong.h"
#include "ffam.h"
#include "ffsr.h"
#include "fknuth.h"
#include "fmarsa.h"
#include "fmultin.h"
#include "fnpair.h"
#include "fres.h"
#include "fspectral.h"
#include "fstring.h"
#include "ftab.h"
#include "fvaria.h"
#include "fwalk.h"
#include "scatter.h"
#include "scomp.h"
#include "sentrop.h"
#include "sknuth.h"
#include "smarsa.h"
#include "smultin.h"
#include "snpair.h"
#include "sres.h"
#include "sspacings.h"
#include "sspectral.h"
#include "sstring.h"
#include "svaria.h"
#include "swalk.h"
#include "swrite.h"
#include "uautomata.h"
#include "ubrent.h"
#include "ucarry.h"
#include "ucrypto.h"
#include "rijndael-alg-fst.h"
#include "tu01_sha1.h"
#include "ucubic.h"
#include "udeng.h"
#include "ufile.h"
#include "ugfsr.h"
#include "ugranger.h"
#include "uinv.h"
#include "uknuth.h"
#include "ulcg.h"
#include "ulec.h"
#include "umarsa.h"
#include "umrg.h"
#include "unif01.h"
#include "unumrec.h"
#include "uquad.h"
#include "usoft.h"
#include "utaus.h"
#include "utezuka.h"
#include "utouzin.h"
#include "uvaria.h"
#include "uweyl.h"
#include "uwu.h"
#include "uxorshift.h"

#endif
