
 
/* unumrec.h for ANSI C */

#ifndef UNUMREC_H
#define UNUMREC_H
 
#include "unif01.h"


unif01_Gen * unumrec_CreateRan0 (long s);



unif01_Gen * unumrec_CreateRan1 (long s);



unif01_Gen * unumrec_CreateRan2 (long s);


void unumrec_DeleteGen (unif01_Gen *gen);


 
#endif
 

