/* include/gdefconf.h.  Generated from gdefconf.h.in by configure.  */
/* gdef.h  for ANSI C */
#ifndef GDEFCONF_H
#define GDEFCONF_H

/* #undef HAVE_LEBOOL */

#define HAVE_LONG_LONG 1

#define HAVE_ERF 1

#define HAVE_RANDOM 1

#define HAVE_LGAMMA 1

#define HAVE_GMP_H 1

/* #undef HAVE_MATHEMATICA */

#define HAVE_SYS_UTSNAME_H 1

#define HAVE_UNISTD_H 1

#define HAVE_STDINT_H 1

#define HAVE_UINT32_T 1

#define HAVE_UINT8_T 1

#endif
